@@ -137,6 +137,9 @@ k8s_opts = [
     cfg.BoolOpt('enable_manager',
                 help=_("Enable Manager to manage the pools."),
                 default=False),
+    cfg.IntOpt('watch_retry_timeout',
+               help=_('Time (in seconds) the watcher retries watching for.'),
+               default=60),
 ]
 
 neutron_defaults = [
@@ -158,6 +161,10 @@ neutron_defaults = [
     cfg.StrOpt('external_svc_subnet',
                help=_("Optional external subnet ID for Kubernetes services"),
                default=None),
+    cfg.IntOpt('lbaas_activation_timeout',
+               help=_("Time (in seconds) that kuryr controller waits for "
+                      "neutron LBaaS to be activated"),
+               default=300),
 ]
 
 octavia_defaults = [
